@@ -2,7 +2,7 @@ package Podman::Images;
 
 use Mojo::Base 'Podman::Client';
 
-use Mojo::Collection;
+use Mojo::Collection qw(c);
 use Scalar::Util qw(blessed);
 
 use Podman::Image;
@@ -19,13 +19,12 @@ sub list {
   }
 
   my $images = $self->get('images/json', parameters => {all => 1},)->json;
-
   my @list = map {
-    my ($name) = split /:/, $_->{Names}->[0] || 'none';
+    my ($name) = split /:/, $_->{Names}->[0] || $_->{Id};
     $self->names_only ? $name : Podman::Image->new(name => $name);
   } @{$images};
 
-  return Mojo::Collection->new(@list);
+  return c(@list);
 }
 
 sub prune {
@@ -72,8 +71,7 @@ L<Podman::Images> implements following attributes.
 
 =head2 names_only
 
-If C<true>, C<list> returns L<Mojo::Collection> of image names only instead of L<Podman::Image> objects, defaults to
-C<false>.
+If C<true>, C<list> returns L<Mojo::Collection> of image names, defaults to C<false>.
 
 =head1 METHODS
 
@@ -81,9 +79,10 @@ L<Podman::System> implements following methods, which can be used as object or c
 
 =head2 list
 
-    my $list = Podman::Images->list;
+    my $list = Podman::Images->list(names_only => 1);
 
-Returns a L<Mojo::Collection> of L<Podman::Image> objects or image names only of stored images.
+Returns a L<Mojo::Collection> of L<Podman::Image> objects or image names only of stored images. See attribute
+C<names_only>.
 
 =head2 Prune
 
